@@ -33,7 +33,7 @@
 /*
  * certt.h - public data structures for the certificate library
  *
- * $Id: certt.h,v 1.6 2001/01/31 18:01:48 wtc%netscape.com Exp $
+ * $Id: certt.h,v 1.16 2002/03/15 20:21:45 wtc%netscape.com Exp $
  */
 #ifndef _CERTT_H_
 #define _CERTT_H_
@@ -49,13 +49,21 @@
 #include "prio.h"
 #include "prmon.h"
 
+/* Stan data types */
+struct NSSCertificateStr;
+struct NSSTrustDomainStr;
+
 /* Non-opaque objects */
 typedef struct CERTAVAStr                        CERTAVA;
 typedef struct CERTAttributeStr                  CERTAttribute;
 typedef struct CERTAuthInfoAccessStr             CERTAuthInfoAccess;
 typedef struct CERTAuthKeyIDStr                  CERTAuthKeyID;
 typedef struct CERTBasicConstraintsStr           CERTBasicConstraints;
+#ifdef NSS_CLASSIC
 typedef struct CERTCertDBHandleStr               CERTCertDBHandle;
+#else
+typedef struct NSSTrustDomainStr                 CERTCertDBHandle;
+#endif
 typedef struct CERTCertExtensionStr              CERTCertExtension;
 typedef struct CERTCertKeyStr                    CERTCertKey;
 typedef struct CERTCertListStr                   CERTCertList;
@@ -160,9 +168,6 @@ struct CERTPublicKeyAndChallengeStr {
     SECItem challenge;
 };
 
-typedef struct _certDBEntryCert certDBEntryCert;
-typedef struct _certDBEntryRevocation certDBEntryRevocation;
-
 struct CERTCertTrustStr {
     unsigned int sslFlags;
     unsigned int emailFlags;
@@ -206,7 +211,7 @@ struct CERTSubjectListStr {
     char *emailAddr;
     CERTSubjectNode *head;
     CERTSubjectNode *tail; /* do we need tail? */
-    struct _certDBEntrySubject *entry;
+    void *entry;
 };
 
 /*
@@ -266,7 +271,7 @@ struct CERTCertificateStr {
     PRBool istemp;
     char *nickname;
     char *dbnickname;
-    certDBEntryCert *dbEntry;		/* database entry struct */
+    struct NSSCertificateStr *nssCertificate;	/* This is Stan stuff. */
     CERTCertTrust *trust;
 
     /* the reference count is modified whenever someone looks up, dups
@@ -392,14 +397,17 @@ struct CERTCrlKeyStr {
 struct CERTSignedCrlStr {
     PRArenaPool *arena;
     CERTCrl crl;
-    certDBEntryRevocation *dbEntry;	/* database entry struct */
-    PRBool keep;			/* keep this crl in the cache for the  session*/
+    void *reserved1;
+    PRBool reserved2;
     PRBool isperm;
     PRBool istemp;
     int referenceCount;
     CERTCertDBHandle *dbhandle;
     CERTSignedData signatureWrap;	/* XXX */
     char *url;
+    SECItem *derCrl;
+    PK11SlotInfo *slot;
+    CK_OBJECT_HANDLE pkcs11ID;
 };
 
 
@@ -777,6 +785,8 @@ typedef struct {
 #include "secasn1t.h"	/* way down here because I expect template stuff to
 			 * move out of here anyway */
 
+SEC_BEGIN_PROTOS
+
 extern const SEC_ASN1Template CERT_CertificateRequestTemplate[];
 extern const SEC_ASN1Template CERT_CertificateTemplate[];
 extern const SEC_ASN1Template SEC_SignedCertificateTemplate[];
@@ -808,7 +818,12 @@ SEC_ASN1_CHOOSER_DECLARE(CERT_CertificateRequestTemplate)
 SEC_ASN1_CHOOSER_DECLARE(CERT_CertificateTemplate)
 SEC_ASN1_CHOOSER_DECLARE(CERT_CrlTemplate)
 SEC_ASN1_CHOOSER_DECLARE(CERT_IssuerAndSNTemplate)
+SEC_ASN1_CHOOSER_DECLARE(CERT_NameTemplate)
 SEC_ASN1_CHOOSER_DECLARE(CERT_SetOfSignedCrlTemplate)
 SEC_ASN1_CHOOSER_DECLARE(CERT_SignedDataTemplate)
+SEC_ASN1_CHOOSER_DECLARE(CERT_SubjectPublicKeyInfoTemplate)
+SEC_ASN1_CHOOSER_DECLARE(SEC_SignedCertificateTemplate)
+
+SEC_END_PROTOS
 
 #endif /* _CERTT_H_ */
