@@ -35,7 +35,7 @@
 #define CKFWM_H
 
 #ifdef DEBUG
-static const char CKFWM_CVS_ID[] = "@(#) $RCSfile: ckfwm.h,v $ $Revision: 1.1 $ $Date: 2000/03/31 19:43:12 $ $Name: NSS_3_2_1_RTM $";
+static const char CKFWM_CVS_ID[] = "@(#) $RCSfile: ckfwm.h,v $ $Revision: 1.2 $ $Date: 2001/12/07 01:35:51 $ $Name: NSS_3_4_1_RTM $";
 #endif /* DEBUG */
 
 /*
@@ -158,4 +158,10 @@ nssCKFWHash_Iterate
   void *closure
 );
 
+NSS_EXTERN void
+nssSetLockArgs(
+   CK_C_INITIALIZE_ARGS_PTR pInitArgs
+);
+
+
 #endif /* CKFWM_H */
