@@ -32,7 +32,7 @@
  */
 
 #ifdef DEBUG
-static const char CVS_ID[] = "@(#) $RCSfile: instance.c,v $ $Revision: 1.3 $ $Date: 2000/09/06 22:23:55 $ $Name: NSS_3_2_1_RTM $";
+static const char CVS_ID[] = "@(#) $RCSfile: instance.c,v $ $Revision: 1.5 $ $Date: 2002/03/06 21:41:34 $ $Name: NSS_3_4_1_RTM $";
 #endif /* DEBUG */
 
 /*
@@ -58,6 +58,7 @@ static const char CVS_ID[] = "@(#) $RCSfile: instance.c,v $ $Revision: 1.3 $ $Da
  *  NSSCKFWInstance_MayCreatePthreads
  *  NSSCKFWInstance_CreateMutex
  *  NSSCKFWInstance_GetConfigurationData
+ *  NSSCKFWInstance_GetInitArgs
  *
  *  -- implement public accessors --
  *  nssCKFWInstance_GetMDInstance
@@ -65,6 +66,7 @@ static const char CVS_ID[] = "@(#) $RCSfile: instance.c,v $ $Revision: 1.3 $ $Da
  *  nssCKFWInstance_MayCreatePthreads
  *  nssCKFWInstance_CreateMutex
  *  nssCKFWInstance_GetConfigurationData
+ *  nssCKFWInstance_GetInitArgs 
  *
  *  -- private accessors --
  *  nssCKFWInstance_CreateSessionHandle
@@ -489,10 +491,6 @@ nssCKFWInstance_CreateMutex
   }
 #endif /* NSSDEBUG */
 
-  if( (NSSArena *)NULL == arena ) {
-    arena = fwInstance->arena;
-  }
-
   mutex = nssCKFWMutex_Create(fwInstance->pInitArgs, arena, pError);
   if( (NSSCKFWMutex *)NULL == mutex ) {
     if( CKR_OK == *pError ) {
@@ -524,6 +522,25 @@ nssCKFWInstance_GetConfigurationData
   return fwInstance->configurationData;
 }
 
+/*
+ * nssCKFWInstance_GetInitArgs
+ *
+ */
+CK_C_INITIALIZE_ARGS_PTR
+nssCKFWInstance_GetInitArgs
+(
+  NSSCKFWInstance *fwInstance
+)
+{
+#ifdef NSSDEBUG
+  if( CKR_OK != nssCKFWInstance_verifyPointer(fwInstance) ) {
+    return (CK_C_INITIALIZE_ARGS_PTR)NULL;
+  }
+#endif /* NSSDEBUG */
+
+    return fwInstance->pInitArgs;
+}
+
 /*
  * nssCKFWInstance_CreateSessionHandle
  *
@@ -1308,3 +1325,23 @@ NSSCKFWInstance_GetConfigurationData
 
   return nssCKFWInstance_GetConfigurationData(fwInstance);
 }
+
+/*
+ * NSSCKFWInstance_GetInitArgs
+ *
+ */
+NSS_IMPLEMENT CK_C_INITIALIZE_ARGS_PTR
+NSSCKFWInstance_GetInitArgs
+(
+  NSSCKFWInstance *fwInstance
+)
+{
+#ifdef DEBUG
+  if( CKR_OK != nssCKFWInstance_verifyPointer(fwInstance) ) {
+    return (CK_C_INITIALIZE_ARGS_PTR)NULL;
+  }
+#endif /* DEBUG */
+
+  return nssCKFWInstance_GetInitArgs(fwInstance);
+}
+
