@@ -32,7 +32,7 @@
  */
 
 #ifdef DEBUG
-static const char CVS_ID[] = "@(#) $RCSfile: token.c,v $ $Revision: 1.4 $ $Date: 2000/09/06 22:23:57 $ $Name: NSS_3_2_1_RTM $";
+static const char CVS_ID[] = "@(#) $RCSfile: token.c,v $ $Revision: 1.7 $ $Date: 2001/11/16 19:41:49 $ $Name: NSS_3_4_1_RTM $";
 #endif /* DEBUG */
 
 /*
@@ -271,15 +271,6 @@ nssCKFWToken_Create
     goto loser;
   }
 
-  fwToken->mdObjectHash = nssCKFWHash_Create(fwToken->fwInstance, 
-                                arena, pError);
-  if( (nssCKFWHash *)NULL == fwToken->mdObjectHash ) {
-    if( CKR_OK == *pError ) {
-      *pError = CKR_GENERAL_ERROR;
-    }
-    goto loser;
-  }
-
   /* More here */
 
   if( (void *)NULL != (void *)mdToken->Setup ) {
@@ -1324,7 +1315,7 @@ nssCKFWToken_OpenSession
 
   if( CK_TRUE == rw ) {
     /* Read-write session desired */
-    if( CK_TRUE != nssCKFWToken_GetIsWriteProtected(fwToken) ) {
+    if( CK_TRUE == nssCKFWToken_GetIsWriteProtected(fwToken) ) {
       *pError = CKR_TOKEN_WRITE_PROTECTED;
       goto done;
     }
@@ -1405,7 +1396,7 @@ nssCKFWToken_GetMechanismCount
   }
 #endif /* NSSDEBUG */
 
-  if( (void *)NULL == fwToken->mdToken->GetMechanismCount ) {
+  if( (void *)NULL == (void *)fwToken->mdToken->GetMechanismCount ) {
     return 0;
   }
 
@@ -1434,7 +1425,7 @@ nssCKFWToken_GetMechanismTypes
   }
 #endif /* NSSDEBUG */
 
-  if( (void *)NULL == fwToken->mdToken->GetMechanismTypes ) {
+  if( (void *)NULL == (void *)fwToken->mdToken->GetMechanismTypes ) {
     /*
      * This should only be called with a sufficiently-large
      * "types" array, which can only be done if GetMechanismCount
