@@ -32,7 +32,7 @@
  */
 
 #ifdef DEBUG
-static const char CVS_ID[] = "@(#) $RCSfile: wrap.c,v $ $Revision: 1.3 $ $Date: 2000/09/06 22:23:57 $ $Name: NSS_3_2_1_RTM $";
+static const char CVS_ID[] = "@(#) $RCSfile: wrap.c,v $ $Revision: 1.6 $ $Date: 2002/03/23 16:10:07 $ $Name: NSS_3_4_1_RTM $";
 #endif /* DEBUG */
 
 /*
@@ -683,9 +683,8 @@ NSSCKFWC_WaitForSlotEvent
   for( i = 0; i < nSlots; i++ ) {
     if( fwSlot == slots[i] ) {
       *pSlot = (CK_SLOT_ID)(CK_ULONG)(i+1);
+      return CKR_OK;
     }
-
-    return CKR_OK;
   }
 
   error = CKR_GENERAL_ERROR; /* returned something not in the slot list */
@@ -2057,8 +2056,8 @@ NSSCKFWC_DestroyObject
     goto loser;
   }
 
-  nssCKFWObject_Destroy(fwObject);
   nssCKFWInstance_DestroyObjectHandle(fwInstance, hObject);
+  nssCKFWObject_Destroy(fwObject);
 
   return CKR_OK;
 
@@ -2514,10 +2513,12 @@ NSSCKFWC_FindObjects
     goto loser;
   }
 
+#ifdef notdef
   arena = nssCKFWSession_GetArena(fwSession, &error);
   if( (NSSArena *)NULL == arena ) {
     goto loser;
   }
+#endif
 
   if( (CK_OBJECT_HANDLE_PTR)CK_NULL_PTR == phObject ) {
     error = CKR_ARGUMENTS_BAD;
@@ -2537,7 +2538,7 @@ NSSCKFWC_FindObjects
 
   for( i = 0; i < ulMaxObjectCount; i++ ) {
     NSSCKFWObject *fwObject = nssCKFWFindObjects_Next(fwFindObjects,
-                                arena, &error);
+                                NULL, &error);
     if( (NSSCKFWObject *)NULL == fwObject ) {
       break;
     }
