@@ -35,7 +35,7 @@
 #define NSSPKIT_H
 
 #ifdef DEBUG
-static const char NSSPKIT_CVS_ID[] = "@(#) $RCSfile: nsspkit.h,v $ $Revision: 1.1 $ $Date: 2000/03/31 19:16:14 $ $Name: NSS_3_2_1_RTM $";
+static const char NSSPKIT_CVS_ID[] = "@(#) $RCSfile: nsspkit.h,v $ $Revision: 1.4 $ $Date: 2001/09/19 19:08:32 $ $Name: NSS_3_4_1_RTM $";
 #endif /* DEBUG */
 
 /*
@@ -160,7 +160,6 @@ typedef struct NSSTrustDomainStr NSSTrustDomain;
  * learned.
  */
 
-struct NSSCryptoContextStr;
 typedef struct NSSCryptoContextStr NSSCryptoContext;
 
 /*
@@ -184,6 +183,9 @@ typedef struct NSSCryptoContextStr NSSCryptoContext;
 struct NSSTimeStr;
 typedef struct NSSTimeStr NSSTime;
 
+struct NSSTrustStr;
+typedef struct NSSTrustStr NSSTrust;
+
 /*
  * NSSUsage
  *
@@ -230,18 +232,24 @@ typedef struct NSSAlgorithmAndParametersStr NSSAlgorithmAndParameters;
  * How OO do we want to make it?
  */
 
-struct NSSCallbackStr;
 typedef struct NSSCallbackStr NSSCallback;
 
-/*
- * NSSModule and NSSSlot -- placeholders for the PKCS#11 types
- */
+struct NSSCallbackStr {
+    /* Prompt for a password to initialize a slot.  */
+    PRStatus (* getInitPW)(NSSUTF8 *slotName, void *arg, 
+                           NSSUTF8 **ssoPW, NSSUTF8 **userPW); 
+    /* Prompt for oldPW and newPW in order to change the 
+     * password on a slot.  
+     */
+    PRStatus (* getNewPW)(NSSUTF8 *slotName, PRUint32 *retries, void *arg,
+                          NSSUTF8 **oldPW, NSSUTF8 **newPW); 
+    /* Prompt for slot password.  */
+    PRStatus (* getPW)(NSSUTF8 *slotName, PRUint32 *retries, void *arg,
+                       NSSUTF8 **password); 
+    void *arg;
+};
 
-struct NSSModuleStr;
-typedef struct NSSModuleStr NSSModule;
-
-struct NSSSlotStr;
-typedef struct NSSSlotStr NSSSlot;
+/* set errors - user cancelled, ... */
 
 typedef PRUint32 NSSOperations;
 /* 1) Do we want these to be preprocessor definitions or constants? */
@@ -256,6 +264,8 @@ typedef PRUint32 NSSOperations;
 #define NSSOperations_VERIFY            0x0040
 #define NSSOperations_VERIFY_RECOVER    0x0080
 
+struct NSSPKIXCertificateStr;
+
 PR_END_EXTERN_C
 
 #endif /* NSSPKIT_H */
